# A comment
a <- function() {}

#+ chunk-label, opt1=value1
"chunk-content"

#- chunk-label, opt1=value1
call(2, 3)
# 21
